@@ -15,7 +15,6 @@ from docker.errors import DockerException
 from datetime import datetime, timedelta, timezone
 from tickerdax import formatting
 from pprint import pformat, pprint
-logging.basicConfig(level=logging.INFO)
 
 
 class TickerDax:
@@ -64,7 +63,7 @@ class TickerDax:
         self._docker_client = None
         self._redis_client = None
 
-        self._cache_folder = os.path.join(os.environ.get(Envs.CACHE_ROOT, tempfile.gettempdir()), f'{NAME}_cache')
+        self._cache_folder = os.environ.get(Envs.CACHE_ROOT, os.path.join(tempfile.gettempdir(), f'{NAME}_cache'))
         self._logger = logging.getLogger(self.__class__.__name__)
         self._logger.setLevel(level=logging.DEBUG)
 
